diff --git a/core/modules/views/src/Entity/View.php b/core/modules/views/src/Entity/View.php
index 167f169..ef6e405 100644
--- a/core/modules/views/src/Entity/View.php
+++ b/core/modules/views/src/Entity/View.php
@@ -253,9 +253,9 @@ public function calculateDependencies() {
     $handler_types = array_keys(Views::getHandlerTypes());
 
     foreach ($executable->displayHandlers as $display) {
       // Add dependency for the display itself.
       /** @var \Drupal\views\Plugin\views\display\DisplayPluginBase $display */
-      $this->addDependency('module', $display->getProvider());
+      $this->calculatePluginDependencies($display);
 
       // Collect all dependencies of all handlers.
       foreach ($handler_types as $handler_type) {
@@ -253,9 +253,9 @@ public function calculateDependencies() {
 
     foreach ($executable->displayHandlers as $display) {
-      // Add dependency for the display itself.
+      // Add dependencies for the display itself.
       /** @var \Drupal\views\Plugin\views\display\DisplayPluginBase $display */
